import os
import unittest
import tempfile
import shutil

from rpkglib.utils import run

class TestCase(unittest.TestCase):

    def setUp(self):
        self.orig_cwd = os.getcwd()
        self.cwd = tempfile.mkdtemp()
        os.chdir(self.cwd)

    def tearDown(self):
        os.chdir(self.orig_cwd)
        shutil.rmtree(self.cwd)

    def init_repo(self):
        run(['git', 'init', '.'])
        run(['git', 'config', 'user.email', 'clime@fedoraproject.org'])
        run(['git', 'config', 'user.name', 'clime'])
        run(['touch', 'README'])
        run(['git', 'add', '-A'])
        run(['git', 'commit', '-m' 'test commit'])
        run(['git', 'remote', 'add', 'origin', 'https://pagure.io/rpkg-util'])
        run(['git', 'config', 'branch.master.remote', 'origin'])

    def repo_head(self):
        return run(['git', 'rev-parse', 'HEAD']).out

    def repo_head_short(self):
        return run(['git', 'rev-parse', '--short=8', 'HEAD']).out

    def tag_id(self, tagname):
        return run(['git', 'rev-parse', tagname]).out

    def init_bare_multibranch_repo(self):
        tmp_repo = tempfile.mkdtemp()
        run(['git', 'init', '--bare', '.'])
        run(['git', 'clone', '.', tmp_repo], capture_stderr=True)
        run(['git', 'config', 'user.email', 'clime@fedoraproject.org'], cwd=tmp_repo)
        run(['git', 'config', 'user.name', 'clime'], cwd=tmp_repo)
        run(['touch', 'README'], cwd=tmp_repo)
        run(['git', 'add', '-A'], cwd=tmp_repo)
        run(['git', 'commit', '-m' 'test commit'], cwd=tmp_repo)
        run(['git', 'branch', 'alt'], cwd=tmp_repo)
        run(['git', 'push', '--all'], cwd=tmp_repo, capture_stderr=True)
        shutil.rmtree(tmp_repo)

    def dump_spec(self, template, outdir=None, name='testpkg', version='1',
                  release='1', source0='source0.tar.gz', **kwargs):

        spec_content = template.substitute(
            kwargs, name=name, version=version,
            release=release, source0=source0)

        if not outdir:
            outdir = self.cwd

        os.makedirs(outdir, exist_ok=True)
        spec_path = os.path.join(outdir, '{0}.spec'.format(name))
        spec_file = open(spec_path, 'w')
        spec_file.write(spec_content)
        spec_file.close()

        return spec_path
